@@ -9,10 +9,17 @@ import typer
 # touch ~/.nssurge-cli/config.ini
 DEFAULT_CONFIG_PATH = Path.home() / ".nssurge-cli" / "config.ini"
 DEFAULT_SURGE_HTTP_API_ENDPOINT = "http://127.1:9999"
+DEFAULT_TRUST_ENV = True
 
 app = typer.Typer(name="config")
 
 
+@app.callback()
+def config_callback():
+    """
+    Manage configuration
+    """
+
 @cache
 def read_config(config_path: Path = DEFAULT_CONFIG_PATH) -> dict:
     """
@@ -23,8 +30,9 @@ def read_config(config_path: Path = DEFAULT_CONFIG_PATH) -> dict:
     config = configparser.ConfigParser()
     config.read(config_path)
     return {
-        "SURGE_HTTP_API_ENDPOINT": config["DEFAULT"]["SURGE_HTTP_API_ENDPOINT"],
+        "SURGE_HTTP_API_ENDPOINT": config.get("DEFAULT", "SURGE_HTTP_API_ENDPOINT", fallback=DEFAULT_SURGE_HTTP_API_ENDPOINT),
         "SURGE_HTTP_API_KEY": config["DEFAULT"]["SURGE_HTTP_API_KEY"],
+        "TRUST_ENV": config.getboolean("DEFAULT", "TRUST_ENV", fallback=DEFAULT_TRUST_ENV),
     }
 
 
@@ -46,6 +54,7 @@ def write_example_config(
     config["DEFAULT"] = {
         "SURGE_HTTP_API_ENDPOINT": DEFAULT_SURGE_HTTP_API_ENDPOINT,
         "SURGE_HTTP_API_KEY": "",
+        "TRUST_ENV": DEFAULT_TRUST_ENV,
     }
     if write_config:
         DEFAULT_CONFIG_PATH.parent.mkdir(parents=True, exist_ok=True)
@@ -75,10 +84,12 @@ def show_config(config_path: Path = DEFAULT_CONFIG_PATH):
     config = read_config(config_path)
     typer.echo(f"SURGE_HTTP_API_ENDPOINT: {config['SURGE_HTTP_API_ENDPOINT']}")
     typer.echo(f"SURGE_HTTP_API_KEY: {config['SURGE_HTTP_API_KEY']}")
+    typer.echo(f"TRUST_ENV: {config['TRUST_ENV']}")
 
 
-def get_creds() -> tuple[str, str]:
+def get_config() -> tuple[str, str, bool]:
     config_dict = read_config()
     SURGE_HTTP_API_ENDPOINT = config_dict["SURGE_HTTP_API_ENDPOINT"]
     SURGE_HTTP_API_KEY = config_dict["SURGE_HTTP_API_KEY"]
-    return SURGE_HTTP_API_ENDPOINT, SURGE_HTTP_API_KEY
+    TRUST_ENV = config_dict["TRUST_ENV"]
+    return SURGE_HTTP_API_ENDPOINT, SURGE_HTTP_API_KEY, TRUST_ENV
