@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 from . import __version__, __app_name__, logger
-from .config import read_config, app as config_app, get_creds
+from .config import read_config, app as config_app, get_config
 from .types import OnOffToggleEnum
 from .utils import (
     bool2color,
@@ -39,15 +39,17 @@ app = typer.Typer(name="modules")
 
 
 async def get_modules():
-    async with SurgeAPIClient(*get_creds()) as client:
+    async with SurgeAPIClient(*get_config()) as client:
         modules = await client.get_modules()
         return await modules.json()
 
 
-@app.callback()
-def get_modules_command():
+@app.callback(invoke_without_command=True)
+def get_modules_command(ctx: typer.Context, output_json: bool = typer.Option(False, "--json", '-j'), pretty_print: bool = typer.Option(False, "--pretty", "-p"), rich_print: bool = typer.Option(False, "--rich", "-r")):
+    if ctx.invoked_subcommand is not None:
+        return
     modules = asyncio.run(get_modules())
-    typer_output_dict(modules)
+    typer_output_dict(modules, output_json, pretty_print, rich_print)
 
 
 # async def set_modules()
